<?php 

/*
Plugin Name: 4Dem.it
Plugin URI: http://www.4dem.it
Description: Iscrizione automatica per blog wordpress
Version: 1.0
Author: Advision srl
Author URI: http://www.advision.it/
*/

define( 'MP_PLUGIN_URL', plugin_dir_url(__FILE__) );
define( 'MP_PLUGIN_PATH', plugin_dir_path(__FILE__) );

class MarketingPlugin {

	private $api;
	private $mp_options;
	private $status;

	public static $fields = array();
	public static $wp_version_required = "3.5";
	public static $check_version = false;

	public function __construct() 
	{
		if (is_admin()) {
			add_action('admin_menu', array($this,'mp_add_admin_menu'), 1);
			add_action('wp_ajax_mp_save_connection', array($this,'mp_save_connection'));
			add_action('wp_ajax_mp_save_lists', array($this,'mp_save_lists'));
			add_action('wp_ajax_mp_save_fields', array($this,'mp_save_fields'));
			add_action('wp_ajax_mp_do_sync', array($this,'mp_do_sync'));
			add_action('wp_ajax_mp_widget', array($this,'mp_widget'));
			add_action('wp_ajax_nopriv_mp_widget', array($this,'mp_widget'));
			
			add_action( 'profile_update', array($this,'mp_profile_update'), 10,2 );
		}

		if (self::$check_version)
			add_filter( 'cmb_meta_boxes', array($this,'mp_metabox'));

		$this->mp_options = get_option("mp_options");

		self::$fields = array('First Name' ,'Last Name' , 'Nickname', 'Display name');

		$this->status = false;

		if (!empty($this->mp_options)) {
			$this->api = new api4marketing( $this->mp_options['server'],
											$this->mp_options['username'],
										 	$this->mp_options['password'] );
			$this->status = $this->api->getStatus();
		} else {
			$this->mp_options = array();
		}

		self::load_style();
        self::load_script();	
	}
	public static function load_style() {
		wp_register_style( 'mp_style', MP_PLUGIN_URL.'/assets/css/style.css' );
		wp_enqueue_style( 'mp_style' );
	}
	public static function load_script() {
	   	if (is_admin()) {
	   		wp_register_script( "mp_ajax", MP_PLUGIN_URL.'/assets/js/admin_ajax.js', array('jquery') );
		} else {
			wp_register_script( "mp_ajax", MP_PLUGIN_URL.'/assets/js/user_ajax.js', array('jquery') );
		}
	   wp_localize_script( 'mp_ajax', 'MPAjax', array( 
		   											'ajaxurl' => admin_url( 'admin-ajax.php' ),
		   											'mp_ajax_nonce' => wp_create_nonce( 'mp_ajax_nonce' ) 
	   											)
	   					);    

	   wp_enqueue_script( 'mp_ajax' );

	}
	public function mp_metabox(array $meta_boxes) {

			$meta_boxes['custom_fields'] = array(
				'id'         => 'custom_fields',
				'title'      => 'Campi Personalizzati',
				'pages'      => array( 'user' ), // Post type
				'context'    => 'normal',
				'priority'   => 'high',
				'show_names' => true, // Show field names on the left
				'fields'     => MP_userFields::cmb_fields()
					/*array(
						'name' => __( 'Default', 'cmb' ),
						'desc' => __( 'Default', 'cmb' ),
						'id'   => $prefix . 'default',
						'type' => 'text',
						// 'repeatable' => true,
						// 'on_front' => false, // Optionally designate a field to wp-admin only
					)*/ 
				
			);

		return $meta_boxes;
	}
	public function mp_add_admin_menu()
	{
		add_menu_page("Impostazioni 4Dem", "4Dem.it", "activate_plugins", "mp_settings", array($this,'mp_settings'), MP_PLUGIN_URL.'assets/img/icon.png');
		add_submenu_page( "mp_settings", "Dati di accesso", "Configurazione", "activate_plugins", "mp_settings" , array($this,'mp_settings'));
		add_submenu_page( "mp_settings", "Liste", "Liste", "activate_plugins", "mp_lists" , array($this,'mp_lists'));
		add_submenu_page( "mp_settings", "Associa i campi", "Associa campi", "activate_plugins", "mp_fields_associations" , array($this,'mp_fields_associations'));
		add_submenu_page( "mp_settings", "Sincronizza", "Sincronizza", "activate_plugins", "mp_sync" , array($this,'mp_sync'));
	}
	public function mp_fields_associations()
	{	
		if ($this->status)
			include_once(MP_PLUGIN_PATH . 'views/fields_associations.php');
		else 
			$this->mp_settings();
	}
	public function mp_settings()
	{	
		include_once(MP_PLUGIN_PATH . 'views/admin.php');
	}
	public function mp_lists()
	{	
		if ($this->status)
			include_once(MP_PLUGIN_PATH . 'views/lists.php');
		else 
			$this->mp_settings();
	}
	public function mp_sync()
	{	
		if ($this->status)
			include_once(MP_PLUGIN_PATH . 'views/sync.php');
		else 
			$this->mp_settings();
	}
	public function update_options($options)
	{
		foreach($options as $key => $value) {
			$this->mp_options[$key] = $value;
 		}
		return update_option("mp_options", $this->mp_options);
	}

	public function mp_save_connection()
	{	
		$nonce = $_POST['mp_ajax_nonce'];
		if ( !wp_verify_nonce( $nonce, "mp_ajax_nonce")) {
      		exit('Non hai i permessi');
   		}

   		$server 	= $_POST['server'];
		$username	= $_POST['username'];
		$password 	= $_POST['password'];

	   	$options = array( 
				'server' 	=> $server,
		   		'username'	=> $username,
		   		'password' 	=> $password,
		);

	   	$api = new api4marketing( $server,$username,$password );

   		$result = array('success' => false, 'msg' => 'I dati inseriti non risultano corretti.');

   		if ($api->getStatus()) {
   			if ($this->update_options($options)) {
   				$result = array('success' => true, 'msg' => 'Connessione avvenuta con successo. Dati salvati!');
   			} else {
   				$result = array('success' => true, 'msg' => 'Connessione avvenuta con successo.');
   			}
   		}

   		echo json_encode($result);

   		die();
	}

	public function mp_save_lists()
	{
		$nonce = $_POST['mp_ajax_nonce'];
		if ( !wp_verify_nonce( $nonce, "mp_ajax_nonce")) {
      		exit('Non hai i permessi');
   		}

   		$subscribers_list 	= $_POST['subscribers_list'];
   		$users_list			= $_POST['users_list'];

   		$options = array(
   				'subscribers_list' => $subscribers_list,
   				'users_list' => $users_list
   		);

   		if ($this->update_options($options)) {
   			$result = array('success' => true, 'msg' => 'Lista salvata con successo!');
   		} else {
   			$result = array('success' => true, 'msg' => 'Nessun cambiamento. Tutto ok!');
   		}
   		
   		echo json_encode($result);

   		die();
	}
	public function mp_save_fields()
	{
		$nonce = $_POST['mp_ajax_nonce'];
		if ( !wp_verify_nonce( $nonce, "mp_ajax_nonce")) {
      		exit('Non hai i permessi');
   		}
		
		$fields = array();
   		$custom_fields = array();

   		foreach ($_POST['fields'] as $key => $value) {
   			if ($value['value'] != 0)
   				$fields[$value['name']] = $value['value'];
   		}

   		$options = array(
   				'fields' => $fields,
   		);

   		if (self::$check_version) {
	   		if (isset($_POST['custom_fields'])) {
		   		foreach ($_POST['custom_fields'] as $key => $value) {
		   			if ($value['value'] != 0)
		   				$custom_fields[$value['name']] = $value['value'];
		   		}
		   		$options['custom_fields'] = $custom_fields;
	   		}
   		}

   		if ($this->update_options($options)) {
   			$result = array('success' => true, 'msg' => 'Campi salvati con successo!');
   		} else {
   			$result = array('success' => true, 'msg' => 'Nessun cambiamento. Tutto ok!');
   		}
   		
   		echo json_encode($result);

   		die();
	}
	public function mp_do_sync()
	{
		if ( !wp_verify_nonce( $_POST['mp_ajax_nonce'], 'mp_ajax_nonce')) {
	    	exit('Non hai i permessi');
	   	}

   		$users = get_users();

   		$usersToAdd = 0;
		$usersToUpd = 0;

		$fields_info = array();
		$fields 	 = $this->mp_options['fields'];

		if (self::$check_version) {
			if ($this->mp_options['custom_fields'])
				$fields = array_merge($this->mp_options['fields'],$this->mp_options['custom_fields']);

			if(Mp_UserFields::fields())
				$this->fields = array_merge(Mp_UserFields::fields(),$this->fields);
		}
	
   		foreach ($users as $user) {
   			
   			foreach (self::$fields as $value) {
   				$field_name = str_replace(" ", "_", strtolower($value));
				$fields_info[$field_name] = get_the_author_meta( $field_name, $user->ID );
			}

   			$this->api->subscribe($this->mp_options['users_list'],$user->user_email,$fields,$fields_info);
   			
   			$response = $this->api->getResponse();

   			if ($response->Success == true) {
   				$usersToAdd++;
   			}

   			if ($response->ErrorCode == 9) {

				$subscriber = $this->api->getSubscriber($this->mp_options['users_list'],$user->user_email);

				$updResponse = $this->api->updSubscriber($subscriber->SubscriberID,$this->mp_options['users_list'],$user->user_email,$fields,$fields_info);

				if ($updResponse) {
					$usersToUpd++;
				}
			}

   		}
   		echo json_encode(array('usersToAdd' => $usersToAdd, 'usersToUpd' => $usersToUpd));

   		die();
	}
	public function mp_widget()
	{

		$nonce = $_POST['mp_ajax_nonce'];
		if ( !wp_verify_nonce( $nonce, "mp_ajax_nonce")) {
      		exit('Non hai i permessi');
   		}

   		$email = $_POST['email'];

   		if ($this->status) {
   			if($this->api->subscribe($this->mp_options['subscribers_list'],$email)) {
   				$result = array('success' => true, 'msg' => 'Ti sei registrato alla nostra newsletter!');
   			} else {
   				$result = array('success' => true, 'msg' => 'Risulti gia essere registrato!');
   			}
   		} else {
   			$result = array('success' => true, 'msg' => 'Servizio momentaneamente non disponibile.');
   		}

   		echo json_encode($result);

   		die();
	}
	public function mp_profile_update($user_id, $old_user_data = false)
	{	
		
		$fields_info = array();
		$fields 	 = $this->mp_options['fields'];

		if (self::$check_version) {
			if ($this->mp_options['custom_fields'])
				$fields = array_merge($this->mp_options['fields'],$this->mp_options['custom_fields']);

			if(Mp_UserFields::fields())
				$this->fields = array_merge(Mp_UserFields::fields(),$this->fields);
		}

		foreach (self::$fields as $value) {
   			$field_name = str_replace(" ", "_", strtolower($value));
			$fields_info[$field_name] = get_the_author_meta( $field_name, $user_id );
		}
		
		$user_email = get_the_author_meta('user_email', $user_id);
		
		if ($old_user_data) {
			if ($user_email != $old_user_data->user_email) {
				$user_email = $old_user_data->user_email;
			}
		}

		$subscriber = $this->api->getSubscriber($this->mp_options['users_list'],$user_email);
		//var_dump($subscriber,$user_email);
		$user_email = get_the_author_meta('user_email', $user_id);
		//var_dump($user_email);
		$this->api->updSubscriber($subscriber->SubscriberID,$this->mp_options['users_list'],$user_email,$fields,$fields_info);
		//die();
	}

}
global $wp_version;
if (version_compare($wp_version, MarketingPlugin::$wp_version_required, '>=')) {
	MarketingPlugin::$check_version = true;
}

add_action('init', function(){

	//including the required files
	include_once(MP_PLUGIN_PATH . 'lib/api4marketing.php');
	include_once(MP_PLUGIN_PATH . 'lib/user_fields.php');
		
	new MarketingPlugin();
	
	if (MarketingPlugin::$check_version) 
		new MP_UserFields();
	
	if (class_exists('Woocommerce')) {
		include_once(MP_PLUGIN_PATH . 'lib/mp_wc_extension.php');
		new MP_WC();
	}

	if (class_exists('Jigoshop')) {
		include_once(MP_PLUGIN_PATH . 'lib/mp_js_extension.php');
		new MP_JS();
	}
	
	if ( MarketingPlugin::$check_version && !class_exists( 'cmb_Meta_Box' ) )
		require_once MP_PLUGIN_PATH. 'cmb/init.php';

}, 9999);


add_action( 'widgets_init', function(){

	include_once(MP_PLUGIN_PATH . 'lib/widget.php');

	register_widget( 'MP_widget' );

});

?>