<?php
class api4marketing {

    private $server;
    private $user;
    private $password;
    private $sessionID;
    private $status;
    private $response;

    public function __construct($server,$user,$password) {

        $this->server       = $server;
        $this->user         = $user;
        $this->password     = $password;

        $this->status       = false;
        $this->sessionID    = false;

        $this->login();
    }

    private function call($data = array(), $isJson = false) {

        if  ($isJson) {
            $argString = json_encode($data);
        } else {
            $argString = implode('&',$data);
        }

        $defaults = array(
            CURLOPT_POST => 1,
            CURLOPT_HEADER => 0,
            CURLOPT_URL => $this->server.'/api.php',
            CURLOPT_USERAGENT => '4marketing',
            CURLOPT_FRESH_CONNECT => 1,
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_FORBID_REUSE => 1,
            CURLOPT_TIMEOUT => 60,
            CURLOPT_SSL_VERIFYPEER => 0,
            CURLOPT_SSL_VERIFYHOST => 0,
            CURLOPT_POSTFIELDS => $argString
        );

        $ch = curl_init();

        curl_setopt_array($ch, $defaults);

        $response = curl_exec($ch);

        curl_close($ch);

        $response = json_decode($response);

        return $response;
    }

    public function login() {

        $login = array();
        $login[] = "Command=User.Login";
        $login[] = "ResponseFormat=JSON";
        $login[] = "Username=".$this->user;
        $login[] = "Password=".$this->password;

        $response = $this->call($login);

        $this->response = $response;

        if (!$response) {
            $this->status = false;
            return false;
        }
        if ($response->Success == true) {
            $this->status = true;
            $this->sessionID = $response->SessionID;
        }

        return $this->status;
    }

    public function getLists() {

        $lists = array();
        $lists[] = "Command=Lists.Get";
        $lists[] = "ResponseFormat=JSON";
        $lists[] = "SessionID=".$this->sessionID;
        $lists[] = "OrderField=ListID";
        $lists[] = "OrderType=ASC";

        $response = $this->call($lists);

        $this->response = $response;

        if ($response) {
            if ($response->Success == true) {
                return $response->Lists;
            }
        }
        return false;
    }

    public function getCustomFields($listId) {

        $customFields = array();
        $customFields[] = "Command=CustomFields.Get";
        $customFields[] = "ResponseFormat=JSON";
        $customFields[] = "SessionID=".$this->sessionID;
        $customFields[] = "OrderField=FieldName";
        $customFields[] = "OrderType=ASC";
        $customFields[] = "SubscriberListID=".$listId;

       $response = $this->call($customFields);

       $this->response = $response;

       if ($response) {
            if ($response->Success == true) {
                return $response->CustomFields;
            }
        }
        return false;
    }

    public function subscribe($listId,$email,$customFields = false, $customerInfo = false) {

        $subscribe = array();
        $subscribe[] = "Command=Subscriber.Subscribe";
        $subscribe[] = "ResponseFormat=JSON";
        $subscribe[] = "TriggerAutoresponder=true";
        $subscribe[] = "ListID=".$listId;
        $subscribe[] = "EmailAddress=".$email;

        if ($customFields) {
            foreach ($customFields as $key => $field) {
               $subscribe[] = "CustomField".$field."=".$customerInfo[$key];
            }
        }
        $subscribe[] = "IPAddress=".$_SERVER['REMOTE_ADDR'];

        $response = $this->call($subscribe);

        $this->response = $response;

        if ($response) {
            if ($response->Success == true) {
                return true;
            }
        }
        return false;
    }

    public function getSubscriber($listId,$email) {
        $subscriberGet = array();
        $subscriberGet[] = "SessionID=".$this->sessionID;
        $subscriberGet[] = "Command=Subscribers.Get";
        $subscriberGet[] = "ResponseFormat=JSON";
        $subscriberGet[] = "OrderField=EmailAddress";
        $subscriberGet[] = "OrderType=DESC";
        $subscriberGet[] = "RecordsFrom=0";
        $subscriberGet[] = "RecordsPerRequest=1";
        $subscriberGet[] = "SearchField=EmailAddress";
        $subscriberGet[] = "SearchKeyword=".$email;
        $subscriberGet[] = "SubscriberListID=".$listId;
        $subscriberGet[] = "SubscriberSegment=Active";

        $response = $this->call($subscriberGet);

        $this->response = $response;

        if ($response) {
            if ($response->Success == true) {
                return $response->Subscribers[0];
            }
        }
        return false;
    }

    public function updSubscriber($subscriberID,$listId,$email,$customFields = false, $customerInfo = false) {

        $ArrayPostParameters = array();
        $ArrayPostParameters[] = "SessionID=".$this->sessionID;
        $ArrayPostParameters[] = "Command=Subscriber.Update";
        $ArrayPostParameters[] = "ResponseFormat=JSON";
        $ArrayPostParameters[] = "SubscriberID=".$subscriberID;
        $ArrayPostParameters[] = "SubscriberListID=".$listId;
        $ArrayPostParameters[] = "EmailAddress=".$email;

        if ($customFields) {
            foreach ($customFields as $key => $field) {
               $ArrayPostParameters[] = "Fields[CustomField".$field."]=".$customerInfo[$key];
            }
        }

        $ArrayPostParameters[] = "Access=admin";

        $response = $this->call($ArrayPostParameters);

        $this->response = $response;

        if ($response) {
            if ($response->Success == true) {
                return true;
            }
        }
        return false;
    }

    public function unsubscribe($listId,$email) {

        $unsubscribe = array();
        $unsubscribe[] = "Command=Subscriber.Unsubscribe";
        $unsubscribe[] = "ResponseFormat=JSON";
        $unsubscribe[] = "SessionID=".$this->sessionID;
        $unsubscribe[] = "ListID=".$listId;
        $unsubscribe[] = "CampaignID=";
        $unsubscribe[] = "EmailAddress=".$email;
        $unsubscribe[] = "Preview=0";
        $unsubscribe[] = "IPAddress=".$_SERVER['REMOTE_ADDR'];

        $response = $this->call($unsubscribe);

        $this->response = $response;

        if ($response) {
            if ($response->Success == true) {
                return $response->Subscribers[0];
            }
        }
        return false;
    }

    public function getStatus() {
       return $this->status;
    }

    public function getResponse()
    {
        return $this->response;
    }
}
?>