<?php
/**
 * Adds MP_widget widget.
 */
class MP_widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'mp_widget', // Base ID
			'4Dem Widget',
			array( 'description' => 'Permette ai visitatori l\'iscrizione alla newsletter. ') // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );

		$label_email = $instance['label_email'];
		$label_btn = $instance['label_btn'];
		$description = $instance['description'];

		$form = '<form method="POST" action="#" id="mp_widget_form">
					<div class="error" id="error" style="display:none;"><strong><p id="error"></p></strong></div>
					<div class="updated" id="success" style="display:none;"><strong><p id="success"></p></strong></div>
					<p>
						<label for="'.$label_email.'">'.$label_email.'</label>
						<input type="text" name="email" id="'.$label_email.'" value=""/><br />
						<span>'.$description.'</span>
					</p>
					<button type="submit">Iscriviti</button>
				</form>';

		echo $args['before_widget'];
		echo $args['before_title'] . $title . $args['after_title'] . $form . $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$title = "Iscriviti alla newsletter";
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		$label_email = "";
		if ( isset( $instance[ 'label_email' ] ) ) {
			$label_email = $instance[ 'label_email' ];
		}
		$description = "";
		if ( isset( $instance[ 'description' ] ) ) {
			$description = $instance[ 'description' ];
		}
		$label_btn = "";
		if ( isset( $instance[ 'label_btn' ] ) ) {
			$label_btn = $instance[ 'label_btn' ];
		}
		?>
		<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>">Titolo</label>
		<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
		<label for="<?php echo $this->get_field_id( 'label_email' ); ?>">Label E-mail</label>
		<input id="<?php echo $this->get_field_id( 'label_email' ); ?>" name="<?php echo $this->get_field_name( 'label_email' ); ?>" type="text" value="<?php echo esc_attr( $label_email ); ?>" />
		</p>
		<p>
		<label for="<?php echo $this->get_field_id( 'description' ); ?>">Testo descrittivo</label>
		<input id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" type="text" value="<?php echo esc_attr( $description ); ?>" />
		</p>
		<p>
		<label for="<?php echo $this->get_field_id( 'label_btn' ); ?>">Testo pulsante</label>
		<input id="<?php echo $this->get_field_id( 'label_btn' ); ?>" name="<?php echo $this->get_field_name( 'label_btn' ); ?>" type="text" value="<?php echo esc_attr( $label_btn ); ?>" />
		</p>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['label_email'] = ( ! empty( $new_instance['label_email'] ) ) ? strip_tags( $new_instance['label_email'] ) : 'Email';
		$instance['label_btn'] = ( ! empty( $new_instance['label_btn'] ) ) ? strip_tags( $new_instance['label_btn'] ) : 'Iscriviti';
		$instance['description'] = ( ! empty( $new_instance['description'] ) ) ? strip_tags( $new_instance['description'] ) : '';

		return $instance;
	}

} // class MP_widget
?>